#!/usr/bin/env python
#-*- coding: utf-8 -*-
"""
Init Script.
Takes the templates from the `templates` directory, parses them and fills it
using the configuration file, and writes them down in the talk root.
"""
import os
from optparse import OptionParser
from ConfigParser import ConfigParser
import datetime

DEFAULT_TITLE = 'unknown title'
DEFAULT_AUTHOR = 'unknown author'
DEFAULT_EVENT = 'unknown event'
DEFAULT_TEMPLATE_DIR = 'templates/'

def parse_options():
    """Option parser, send back options and args"""
    parser = OptionParser()
    parser.add_option('-c', '--conf-file', dest='config_file',
        default="talk.conf",
        help='set the config filepath (default is talk.conf)', 
    )
    parser.add_option('-t', '--templates-dir', dest='templates_dir',
        default=DEFAULT_TEMPLATE_DIR,
        help="set the templates directory (default is `templates/`)"
    )
    
    (options, args) = parser.parse_args()
    return options, args


def load_configuration(filepath):
    """Load configuration extracted from the filepath"""
    title, author, event = DEFAULT_TITLE, DEFAULT_AUTHOR, DEFAULT_EVENT
    date = str(datetime.date.today())
    year = str(datetime.date.today().year)
    if os.path.isfile(filepath):
        config = ConfigParser()
        config.read(filepath)
        title = config.get('talk', 'title')
        author = config.get('talk', 'author')
        event = config.get('talk', 'event')
        # date variables
        date_value = config.get('talk', 'date')
        date_object = datetime.datetime.strptime(date_value, "%Y-%d-%m")
        # date and year assignment
        date = str(date_object)
        year = str(date_object.year)
    return {
        'title': title,
        'author': author,
        'event': event,
        'date': date,
        'year': year,
    }


def filter_content(filepath, values):
    """Filters the content by replacing #KEY# by its value."""
    content = open(filepath, 'r').read()
    for key in values:
        searched = "#%s#" % key.upper()
        content = content.replace(searched, values[key])
    return content


def init(templates_dir, values):
    """Reads the template file in the `templates` dir, filters them by
    replacing the variables by their values, and writing them in the talk
    directory."""
    if os.path.isdir(templates_dir):
        for filename in os.listdir(templates_dir):
            filepath = os.path.join(templates_dir, filename)
            # security issue!
            if os.path.isfile(filename):
                print "WARNING! The file `%s` already exists in the project directory." % filename
                overwrite = raw_input('Are you sure you want to overwrite this? [y/N] ')
                if not overwrite.lower().startswith('y'):
                    print "%s skipped" % filename
                    continue
                else:
                    print "%s overwritten" % filename
            content = filter_content(filepath, values)
            open(filename, 'w').write(content)


def main():
    """Main program."""
    options, args = parse_options()
    values = load_configuration(options.config_file)
    # calling the initialisation function
    init(options.templates_dir, values)

if __name__ == '__main__':
    main()
